# Readme for Fatdog64 developers

*Contents*

* **Debugging HTML content and this package**
* **`fd-faq` package build process**
* **Usage**
* - build
* - prep\_html5
* - check\_html\_pub
* - check\_for\_mdview
* - html5\_to\_ihtml
* - ihtml\_to\_md
* **DOs**
* **Learnings**
* - Wrapping lines spells trouble!
* - Don't use this pipeline: `html2 | 2html`

---------------------------------------------------------------------

## Debugging HTML content and this package

Debugging aids can be enabled with environment `DEBUG=1` in some scripts. See script usage.

Some commented-out lines are marked with "DEBUG FILTER".
Uncomment and adapt the line to exclude some input files from the build.
This can be useful to test a specific file without waiting for all other files to build.
Note that you need to uncomment the "DEBUG FILTER" line in each script that you want to speed up.

The build script can run outside chroot. Install packages `pandoc`, `html-tidy` and `gawk`.
To debug a build with a specific set of input HTML files:

```sh
mkdir WORK
cp -t WORK file1.html ...
[DEBUG=1] builder/build.sh WORK
```

Build scripts output to directories `WORK_*`.
See the diagram below, in which `«FAQS»` is like our `WORK`.


## `fd-faq` package build process

![Picture of fd-faq package build](doc/fd-faq.png)

## Usage

### build

```
usage: [DEBUG=1] build.sh INPUT_DIR
exit status:
	0
DEBUG=1:
	Don't create home.md and pass DEBUG=1 to the other scripts."
```

### prep\_html5

```
usage: prep_html5.sh INPUT_DIR OUTPUT_DIR
exit status:
	0 (all OK / tidy warned)
	1 (user error or internal error)
	2 (tidy found errors)"
```

### check\_html\_pub

```
usage: check_html_pub.sh INPUT_DIR
exit status:
	0 (all OK or some warnings)
	1 (user error or internal error - exit immediately)
	3 (some input files exceed mdview's capabilities - exit after testing all files)"
```

### check\_for\_mdview

```
usage: check_for_mdview.sh ( FILEPATH | '-' ) CONDITION_NAME [ARGS]
exit status:
	 0(CONDITION_NAME is true)
	 1(user error or internal error)
	15(CONDITION_NAME is false)

FILEPATH should be first cleaned with prep_html5.sh.

Available condition names and their arguments
---------------------------------------------

list_item_level_gt LEVEL ['_xml2=1'] ['_filepath=1'] ['_label='STRING]

	Is at least one bullet/numbered list item's level > LEVEL?
	'_xml2=1' prints all matching xml2 paths preceded by '_xml2:'.
	'filepath=1' prints '_filepath:'(_label or FILEPATH) if exit status 0.

any_table_warning ['_xml2=1'] ['_filepath=1'] ['_label='STRING]

	Is there <table> tags? Print warning message.
	Only pipe-table equivalent tables will render correctly.
```

### html5\_to\_ihtml

```
usage: html5_to_ihtml.sh INPUT_DIR OUTPUT_DIR
exit status: 0(all OK) >0(error)
```

### ihtml\_to\_md

```
usage: [DEBUG=1] ihtml_to_md.sh INPUT_DIR OUTPUT_DIR
exit status:
	0  (all OK)
	>0 (error)
DEBUG=1:
	Don't create file index faq_file_list.md.
	Create markdown_strict (.mkd) file alongside mdview markdown (.md) file."
```

## DOs

You are an [editor](README-editors.md) too.

After making a new package, publish online HTML faqs from the package itself, not from `pkg/000/fatdog-extra`.
The script that actually created HTML faqs for online publishing is `builder/prep_html5.sh`.

Should `mdview` be improved in the future, update `builder/quirks.sh` to reflect new and changed capabilities.
Scripts `builder/html5_to_ihtml.sh` and `builder/ihtml_to_md.sh` source `builder/quirks.sh`.

## Learnings

### Wrapping lines spells trouble!

Our build pipeline crucially relies on `tidy --wrap 0 | pandoc --wrap=none` to
ensure that HTML code and markdown text lines wrap as little as possible.

Manipulating HTML tags with awk and sed is much easier when one knows that most
tags are guaranteed to open and close on the same line! Note that exceptions
exist. For example, `tidy` always "wraps" a `<ul>` list after each `<li>` item
regardless of the wrapping preference.

Editing pandoc's `markdown_strict` output to make it work for mdview is much
easier when one knows that the first line of a list item is also the _only_
line for that item! Unfortunately, exceptions exist. For instance, pandoc wraps
a list item on each hard-line break that the item text includes. Our build
pipeline includes many work-arounds make list items work for mdview.

### Don't use this pipeline: `html2 | 2html`

In an early implementation I was piping HTML through `html2 | {edit} | 2html` to
simplify selective editing. However, I noticed that 2html 0.5 is buggy. Example:

```html
echo '<p>A</p><p>Z</p>" | html2 | 2html
  <html><body><p>A<p>
  Z
echo '<b>A</b><i>Z</i>' | html2 | 2html
  <html><body><b>A<i>Z
```

