# Readme for Fatdog64 content editors (and devs)

## File names

HTML file names must end with `.html`.

## Write HTML5!

Write HTML**5** (five) content. To assist you in this task, there are two scripts named `prep_html5.sh`, and `check_html_pub.sh` in the `builder` directory. Use them in a write-test-fix workflow cycle until you get zero warnings and zero errors.

Packages `pandoc`, `html-tidy` and `gawk` must be installed.

**Script usage**

	PATH/TO/prep_html5.sh     PATH/TO/CONTENT_DIR PATH/TO/TEMP_DIR
	PATH/TO/check_html_pub.sh                     PATH/TO/TEMP_DIR

* `PATH/TO/CONTENT_DIR` is the pathname of the directory holding the HTML5 you are writing or modifying.
* `PATH/TO/TEMP_DIR` is the pathname of a temporary directory holding prepared¹ HTML5 output files.

[¹] _Prepared HTML5 will be published online_.

### Example of write-test-fix cycle

* Assign the `/PATH/TO/prep_html5.sh` to a variable:    `PREP=./builder/prep_html5.sh`.
* Assign the `PATH/TO/CONTENT_DIR` to a variable:       `CONTENT=./usr/share/doc/faqs`.
* Assign the `PATH/TO/check_html_pub.sh` to a variable: `CHECK=./builder/check_html_pub.sh`.
* Create and empty, temporary directory:                `mkdir PUB`.

**Cycle 1**

* Write/edit an HTML file in the `$CONTENT` directory.
* Run: `rm -f $PUB/*.ERR; $PREP $CONTENT $PUB`.

`$PREP` will not modify in any way the files in `$CONTENT`.
It will write prepared copies of the files in `$CONTENT` and error reports, if any, to `$PUB`.
The name of error report files ends with `.ERR`.
Examine `.ERR` files in `$PUB`, and fix all issues by editing the corresponding files **in `$CONTENT`** (it's easy to get confused and edit the prepared files instead).
Repeat cycle 1 until there are no more `.ERR` files in `$PUB`.

When all files in `$CONTENT` pass the `$PREP` test move to **Cycle 2**

**Cycle 2**

* Run: `rm -f $PUB/*.ERR; $CHECK $CONTENT $PUB`.

If errors are reported in `$PUB` by `.ERR` files, fix the correponding HTML files in the `$CONTENT` directory.
Repeat cycle 2 until there are no more `.ERR` files in `$PUB`.

When all files in `$CONTENT` pass the `$PREP` and `$CHECK` tests you can delete directory `$PUB`.

### Do I really need to clear all `.ERR` files?

You must fix all errors that `$CHECK` reports. You should definitely also fix the errors that `$PREP` reports but you don't have to. In some limited cases it might not be possible to avoid some warnings without effort. For example, if you start from an HTML file that isn't HTML5, and you don't have an alternative source for the same content formatted as HTML5. Then either you manually convert the initial file to HTML5 or you ignore the `.ERR` file.

### Do I really need to write HTML5? Can't I just use HTML whatever?

HTML whatever will hunt you back.

## `mdview` translation support (gettext)

Editors can add `class="mdview-nopot"` to the **block** element tags that
shouldn't be translated in mdview.[²] `<pre>` elements are not translated by
default unless they include `class="mdview-gettext"`.

[²] _See /usr/share/mdview/examples/gettext.md_.

## HTML `<pre>` and fenced code blocks

By default a `<pre>` block in HTML is converted to a fenced code block in
markdown if the tag doesn't include classes or attributes.

HTML
        <pre>
        this text     is     **preformatted**
        </pre>

Markdown
        ```
        this text     is     **preformatted**
        ```

If `<pre>` includes exactly one class, "mdview-gettext",
or if it includes exactly two classes, "mdview-gettext" and "mdview-nopot",
then the output is, again, a fenced markdown block.

HTML
        <pre class="mdview-gettext">
        this text     is     **preformatted**
        </pre>

Markdown
        ```gettext
        this text     is     **preformatted**
        ```

HTML
        <pre class="mdview-gettext mdview-nopot">
        this text     is     **preformatted**
        </pre>

Markdown
        %%nopot yes

        ```gettext
        this text     is     **preformatted**
        ```
        %%nopot no

Any other combination of class values or attribute values output the
traditional, indented code block, and the effect of classes and attributes
depends pandoc, the underlying HTML-markdown conversion engine.

## TABLES

Automatic support for HTML tables is limited to simple tables that only contain text and numbers.
_Simple_ means that table cells do not include block-level elements.

A simple table resembles the cells of a spreadsheet:

| COL 1 | COL 2 | .... | COL N  |
|-------|-------|------|--------|
| some  | text  | 1234 | number |
| more  | text  | 5679 | ...    |

A simple table is rendered as a left-aligned markdown _pipe table_, which the current version of mdview (2023.04) can display as an unstyled code block.

Text with image tables, and all more-complex kinds of tables, are unwrapped to a sequence of markdown text with image blocks.
If the table isn't simple the resulting markdown may include raw HTML, and complex markdown that mdview will render poorly.

The HTML `<table>` tag can be used for layout purposes, that is, to display content blocks in a specific position relative to each other. Mdview doesn't support this table usage.  You can replace table layout with CSS.

* Include style file `pub/div-table.css` into the HTML file's `<head>`.
* Replace table tags with `<div>`s.

See `usr/share/doc/faqs/pub/dis-tbl-example.html` (toy example), and `Networking.html` in the `faqs` directory (actual application).

