#!/bin/sh

# build.sh - build puppeteer for the Fatdog64 FAQ
# Copyright (C) step, 2022-2023 - https://github.com/step-
# License GPL2

usage () {
	echo "usage: [DEBUG=1] ${0##*/} INPUT_DIR
exit status:
	0
DEBUG=1:
	Don't create home.md and pass DEBUG=1 to the other scripts."
}

check_dependencies () { # {{{1
	local missing
	! type -p gawk   > /dev/null && missing="$missing, gawk"
	! type -p html2  > /dev/null && missing="$missing, xml2"
	! type -p pandoc > /dev/null && missing="$missing, pandoc"
	! type -p tidy   > /dev/null && missing="$missing, html-tidy"
	[ -n "$missing" ] && echo >&2 "missing packages: ${missing#?}"
	[ -z "$missing" ]
}

# Main {{{1}}}

trap 'printf >&2 "\033[7m ERROR \033[0m\n"; exit 1' ERR
set -e # KEEP!

check_dependencies

in_dir="${1:?}"                       # HTML sources, read-only
ihtml_out_dir="${in_dir}_ihtml_out"   # work, intermediate markdown
html_pub_dir="${in_dir}_html_pub_out" # HTML for publishing, *.ERR files
md_pub_dir="${in_dir}_md_pub_out"     # markdown for publishing
mkdir -p "$ihtml_out_dir" "$html_pub_dir" "$md_pub_dir"

# -----------------------------------------------------------------------------
# special case - home.html
# -----------------------------------------------------------------------------
# $in_dir is usr/share/doc/faqs -- see diagram in doc/README-devs.md
# The following files are built from $in_dir/home.html:
# - $md_pub_dir/home.md      packaged
# - $in_dir/../home.html     packaged as usr/share/doc/home.html
# - $html_pub_dir/home.html  removed in favor of usr/share/doc/home.html
# Relative links in $in_dir/home.html are adjusted automatically for all cases.
# -----
# ?? unresolved on 20230907: https://distro.ibiblio.org/fatdog/web/home.html
# is an unmanaged superset of $in_dir/../home.html
# -----------------------------------------------------------------------------

echo "===== prep_html5.sh ====="
# args: input_dir output_dir
"${0%/*}/prep_html5.sh" "$in_dir" "$html_pub_dir"

echo "===== check_html_pup.sh ====="
# args: input_dir
"${0%/*}/check_html_pub.sh" "$html_pub_dir"

echo "===== html5_to_ihtml.sh ====="
# args: input_dir output_dir
"${0%/*}/html5_to_ihtml.sh" "$html_pub_dir" "$ihtml_out_dir"

echo "===== ihtml_to_md.sh ====="
# args: input_dir output_dir
"${0%/*}/ihtml_to_md.sh" "$ihtml_out_dir" "$md_pub_dir"

echo "===== build doc/home.html ====="
sed -E -e '
	s:(=")([^/]+\.html"):\1faqs/\2:g
	s:(=")(pub/.+"):\1faqs/\2:g
	s:(=")(img/.+"):\1faqs/\2:g
' "$html_pub_dir/home.html" > "$in_dir/../home.html"
rm "$html_pub_dir/home.html"

exit
