#!/usr/bin/gawk -f

# check_for_mdview.gawk - CONDITION_NAME test engine for check_for_mdview.sh
# Copyright (C) step, 2023
# License GPL2

# usage: [env AWKPATH=this_dir] gawk -f this_file V_OPTIONS [_variable=value...] [FILEPATH]
# exit status:
#	 0(CONDITION_NAME is true)
#	 1(user error or internal error)
#	15(CONDITION_NAME is false)
# -------------------------------------------------
# FILEPATH must be pre-processed with prep_html5.sh
# -------------------------------------------------
# V_OPTIONS:
# -v ACTION="replace_semantic_tag" | ""
# -v MATCH=pattern
# -v TYPE=prefix      output (prefix $0) on /pattern/ match
# _variable=value     defined by our caller check_for_mdview.sh, e.g. _xml2, _filepath, _label

# Depend package: xml2-0.5

@include "shared.gawk"

BEGIN {
	user_error = 0
}

# --------------------------------------------------------------------------- #
### sub: semantic_tag_to_div

# replace semantic tag with <div> because html2 pre-dates HTML5 semantic tags
# this action can be invoked separately from main

BEGIN {
	if (ACTION == "semantic_tag_to_div") {
		tags = @/(.*)(<\/?)(article|aside|details|figcaption|figure|footer|header|main|nav|section)([ \t>].*)/
		pre1 = @/^<pre[ \t>].*/
		pre0 = @/^<\/pre[ \t>].*/
		fpre = 0

		while (getline s > 0) {
			if (s ~ pre1) fpre = 1; else if (s ~ pre0) fpre = 0;
			if (!fpre) {
				for (i = 0; match(s, tags, a) && i < 10; i++) {
					s = a[1]    a[2]    "div"    a[4]    substr(s, RSTART + RLENGTH)
					#s = a[1]"("a[2]")" "div" "("a[4]")" substr(s, RSTART + RLENGTH)"@"i
				}
			}
			print s
		}
		exit 0
	}
}

# --------------------------------------------------------------------------- #

### main: process html2's output
BEGIN {
	if (MATCH == "" || TYPE == "")
		exit (user_error=1)
	pattern = MATCH
	matches[TYPE] = 0
}

match($0, pattern) {
	# ensure the match is part of the xml2 path and not the content text
	prefix = substr($0, 1, RSTART -1)
	if (prefix !~ /^\/html\/[a-z/]+$/)
		next # bogus match

	++matches[TYPE]
	if (_xml2+0)
		print (TYPE $0)
	else
		exit # immediately, without counting further matches, if any
}

END {
	if (user_error)
		exit 1

	if (_filepath+0 && matches[TYPE])
		print "_filepath:" (_label != "" ? _label : FILENAME)

	# errors, non-warnings
	exit (matches[TYPE] ? 0 : 15)
}

