# This file is sourced, not run

# check_for_mdview.sh - check HTML file for some mdview limitation.
# Copyright (C) step, 2023
# License GPL2

# Depend package: xml2-0.5


usage () {
	echo "usage: ${0##*/} ( FILEPATH | '-' ) CONDITION_NAME [ARGS]
exit status:
	 0(CONDITION_NAME is true)
	 1(user error or internal error)
	15(CONDITION_NAME is false)

FILEPATH should be first cleaned with prep_html5.sh.

Available condition names and their arguments
---------------------------------------------

list_item_level_gt LEVEL ['_xml2=1'] ['_filepath=1'] ['_label='STRING]

	Is at least one bullet/numbered list item's level > LEVEL?
	'_xml2=1' prints all matching xml2 paths preceded by '_xml2:'.
	'filepath=1' prints '_filepath:'(_label or FILEPATH) if exit status 0.

any_table_warning ['_xml2=1'] ['_filepath=1'] ['_label='STRING]

	Is there <table> tags? Print warning message.
	Only pipe-table equivalent tables will render correctly.
"
}

die () { # $1-exit_status $2-text
	echo >&2 "${0##*/}: ${2:?}"
	exit ${1:?}
}

do_test() { # $@-options $MATCH $TYPE $FILEPATH
	gawk -f "${0%.*}.gawk" -v ACTION='semantic_tag_to_div' "${FILEPATH:?}" |
		{ html2 || echo >&2 "html2 said in ${0##*/} $FILEPATH"; } |
		gawk -f "${0%.*}.gawk" -v MATCH="${MATCH:?}" -v TYPE="${TYPE:?}" _label="$FILEPATH" "$@"
		# set _label because gawk runs downstream of pipe; $@ may still override our _label
}

list_item_level_gt() { # $1-level [$2@-options] # {{{1
	local level=${1:?}; shift
	local pat='/(ol|ul)/' # / is the xml2 pathname component separator
	local i=1 regex="$pat"     # gawk $regex matches $level times $pat

	while [ $i -le $level ]; do
		regex="$regex""[^/=]*$pat"
		i=$(($i + 1))
	done
	# restrict matches to xml2 terminal <li> paths with text content,  e.g. .../li=content$
	# we don't want to match xml2 paths of intermediate tags,          e.g. .../ul/li/ul/li/em$
	regex="$regex[^=]*li="

	local MATCH="$regex" TYPE="@ERROR@" FILEPATH="$filepath"
	do_test "$@"
	ret=$?
	return $ret
}

any_table_warning() { # [$1@-options] # {{{1
	local regex='/table/.*/td=' # / is the xml2 pathname component separator
	local ret=0

	local MATCH="$regex" TYPE="@WARNING@" FILEPATH="$filepath"
	do_test "$@"
	ret=$?
	case $ret in
	0)  : 'any_table_warning is true'
		printf >&2 "\n\033[7m WARNING file %s: found <table> tag\033[0m\n" "${filepath##*/}"
		printf >&2 "Only pipe tables are OK. More complex tables trash mdview markdown.\n"
		ret=15 # not an error because mdview can at least show pipe tables
		;;
	esac
	return $ret
}

### main {{{1}}}

filepath="$1" condition_name="$2"
[ $# -gt 2 ] && shift 2

if [ "$filepath" = "-h" -o "$filepath" = "--help" ]; then
	usage; exit
fi
if ! command -V "$condition_name" 2>&1 | grep -q ' \?function \?'; then
	usage; die 1 "invalid CONDITION_NAME '$condition_name'"
fi
if [ "$filepath" != "-" -a ! -f "$filepath" ] ; then
	usage; die 1 "invalid FILEPATH '$filepath' on CONDITION_NAME '$condition_name'"
fi

$condition_name "$@"
ret=$?
[ $ret -eq 1 ] && die 1 "user error or internal error on CONDITION_NAME '$condition_name'"
exit $ret
