#!/bin/sh

# html5_to_ihtml.sh - work-around mdview's markdown quirks
# Copyright (C) step, 2023
# License GPL2

#
# Edit all .html files in INPUT_DIR and write results to OUTPUT_DIR.
# INPUT_DIR  holds "normalized" HTML (see ./prep_html5.sh).
# OUTPUT_DIR holds intermediate HTML (see ./ihtml_to_md.sh).
#
# This script massages HTML to work around limitations of mdview markdown viewer
# and stylistic differences between HTML and mdview's GTK2 output. It outputs
# an intermediate HTML form that should lead to mdview-friendly markdown.

usage () {
	echo "usage: ${0##*/} INPUT_DIR OUTPUT_DIR"
	echo "exit status: 0(all OK) >0(error)"
}

### main

. "${0%/*}/shared.sh" || exit 1

die_unless_in_dir_out_dir "$@" # => $in_dir $out_dir

#. "${0%.sh}_bbtest.sh" || die 1 "error while sourcing black-box tests"

die_unless_some_file "$in_dir" html

. "${0%/*}/quirks.sh" || die 1 "error while sourcing quirks configuration"

gawk -f "${0%.sh}.gawk" -v OUT_DIR="$out_dir" $QUIRKS_AWK_V "$in_dir"/*.html

