
-- local log = require 'logging'; log = log.temp
local my  = require 'shared'
local mdview_markdown = my.get_mdview_markdown()
local mdview_max_atx_level = tonumber(os.getenv 'mdview_max_atx_level')
local mdview_insert_line_before_atx12 = os.getenv 'mdview_insert_line_before_atx12' == '1'
local mdview_can_jump_to_anchor = tonumber(os.getenv 'mdview_can_jump_to_anchor')

function replace_bold_text_for_atx (hdr) -- Header
	if mdview_can_jump_to_anchor == 2 and hdr.identifier then
		-- TODO Should mdview ever support jumping to sections:
		--   * stash hdr.identifier value (ID) and insert '<span id="ID"></span>' before the heading
		--   * in ./ihtml_to_md.sh convert the span to a markdown "section jump target" of sort for mdview
		--   * possible extend the same kind of id= support to other tags besides <hN>
	end

	-- pad content with box drawings vertical bar to avoid the following
	-- case: <h4 id="search">search=<em>n</em></h4> => **search=*n***
	-- mdview 2023.04 can't "do the right thing" with three adjacent
	-- asterisks, and shows a blank page! Note that mdview does work
	-- correctly if given **search=\*n\***
	hdr.content:insert(1,"\u{2551} "); hdr.content:insert(" \u{2551}") -- ║

	-- this transformation drops attributes, classes and id, if any
	-- and implicitly "demotes" hdr's pandoc type from 'Block' to 'table'
	hdr = {
		pandoc.SoftBreak(),
		pandoc.Strong(hdr.content),
		pandoc.SoftBreak(),
	}

	return hdr
end


function insert_lines_atx (hdr) -- Header
	if not hdr or hdr.level > 2 then
		return hdr
	end

	local texts = pandoc.List{}
	local fmt = '%s\n'
	local lo

	lo = pandoc.List(hdr.content)
	if lo and #lo > 0 then
		texts = my.get_texts(lo)
		if texts and #texts > 0 then
			if hdr.level == 1 then
				fmt = '\u{00A0}\n# %s\n# \u{00A0}\n'
			elseif hdr.level == 2 then
				fmt = '\u{00A0}\n## %s\n'
			end
			texts = pandoc.utils.stringify(texts)
			hdr.content = pandoc.RawInline(mdview_markdown, fmt:format(texts))
		end
	end

	return hdr
end


------------------------------------------------------------------------
--                               Header                               --
------------------------------------------------------------------------

-- (1) --
-- Replace <h4> and higher level headings with bold text

-- (2) --
-- Add a line before headings level 1 and 2 and after level 1 to give some
-- vertical breathing The method relies on the fact that mdview merges consecutive
-- headings together. See /usr/share/mdview/examples/br_heading_test.md.
-- The added headings need to include some text to be valid ATX headings. I'm
-- using a non-breaking space for a distictive enough pattern that grep/sed
-- could match if needed. non-breaking space &nbps; U+00A0

function Header (hdr)
	-- log('heading level', hdr.level, 'id', hdr.identifier)

-- (1) --
	if hdr.level > mdview_max_atx_level then
		-- may not come out as a Header anymore
		hdr = replace_bold_text_for_atx (hdr)
	end

-- (2) --
	if mdview_insert_line_before_atx12 and
		-- it's still a Header
		pandoc.utils.type(hdr) == 'Block'
	then
		hdr = insert_lines_atx (hdr)
	end

	return hdr
end

