# This file is sourced, not run

# setup_tidy.sh - set up html-tidy run for prep_html5.sh
# Copyright (C) step, 2023
# License GPL2


# https://api.html-tidy.org Options and API Reference cards for release versions

# Configure:
# $tidy_options


# ----- TIDY OPTIONS -----------------------------------------------------{{{
# ./tidy.conf is an equivalent, fully-documented file with all default values
# HTML Tidy has so many options. Maybe only pandoc can beat it.


tidy_options="-quiet"

# do not print out comments
tidy_options="$tidy_options --hide-comments yes"

# do not add Tidy's meta element
tidy_options="$tidy_options --tidy-mark no"

# replace smart quotes and em dashes with ASCII, and non-breaking spaces with spaces
tidy_options="$tidy_options -bare"

# This option specifies the right margin Tidy uses for line wrapping. Tidy tries
# to wrap lines so that they do not exceed this length. Set wrap to zero to
# disable line wrapping.
# Disable wrapping because it makes "diffing" revisions more "noisy" for
# translators. Wrapping also make post-processing output markdown with sed/awk
# more difficult and less predictable.
# =============================================================================
# Notes to Fatdog64 devs: we edit HTML files before they go through this filter,
# exactly as they came from a checkout. However, we publish the output of
# this filter to the web.
# =============================================================================
tidy_options="$tidy_options --wrap 0"

# This option specifies if Tidy should enclose any text it finds in the body
# element within a <P> element. This is useful when you want to take existing HTML
# and use it with a style sheet.
# Enable this option. The effect of this + `wrap 0` is that split text lines will
# be joined onto a single line. We want this for the same reasons that we disable
# wrapping altogether. Also, "yes" makes the HTML agreeable to `html2`.
tidy_options="$tidy_options --enclose-text yes"

# Ensure the same error/warning reporting format that prep_html5.gawk expects.
# line <line number> column <column number> - (Error|Warning): <message>
tidy_options="$tidy_options --gnu-emacs no --show-filename no"

# This option specifies if Tidy should output tag names in upper case.
# Ensure lowercase as prep_html5.gawk expects.
tidy_options="$tidy_options --uppercase-tags no"

# This option allows prioritizing the writing of attributes in tidied documents.
# This option takes a space or comma separated list of attribute names.
# We use this feature only for case 1 of html5_to_ihtml.sh (link rewriting).
tidy_options="$tidy_options --priority-attributes href,id,name"

# This option specifies if Tidy should preserve well-formed entities as found in the input.
# [step] With the default value (no) this input HTML '<pre>a &amp;&amp; b</pre>'
# becomes '<pre>a &amp;& b</pre>' (tidy 5.8.0), which looks like a bug to me. I
# think it's better to expect editor's entities are corrent and preserve them.
# =============================================================================
# Notes to Fatdog64 devs: Upgrading tidy looks risky. Upstream is (unreleased)
# version 5.9.20 with 155 open bugs, at least one of which is a showstopper
# for us: https://github.com/htacg/tidy-html5/issues/1094
# (Tidy mangles whitespace in pre and code tags).
# =============================================================================
tidy_options="$tidy_options --preserve-entities yes"

