# shared awk patterns and functions

BEGIN {
	FATDOG_FAQ_DIR_URL = "https://distro.ibiblio.org/fatdog/web/faqs"
}

# set SN = the gawk script name
BEGIN {
	for (i = 0; i < (__ = length(PROCINFO["argv"])); i++) {
		if (substr(_ = PROCINFO["argv"][i], 1, 2) == "-f") {
			SN = length(_) > 2 ? substr(_, 3) : (i - 1 < __ ? PROCINFO["argv"][i + 1] : "")
			sub(/.*\//, "", SN)
			break
		}
	}
}

# shorten a path for terse messages
function pretty(p) {
	sub(/.*\/pkg\//, "pkg/", p)
	return p
}

########################
#  markdown templates  #
########################

# runs on FNR == 1 before any other output, after BEGIN
function fd_header () {
# GETTEXT
if (mdview_enable_gettext_support+0) {
print "%%textdomain fatdoghelp"
print ""
}

# LOGO
# Insert `&nbps;` before the logo for cosmetic reasons. The mdview MardownText
# widget inserts a visible text caret before the first character in the render
# buffer, and sizes the caret to the height of whatever follows the caret,
# which happens to be our 100px tall logo. So the caret's width scales up
# proportionally to 100px, and the caret looks like an ugly, thick vertical
# black line segment.  Work around: by inserting `&nbsp;` the caret is as tall
# as the default font size, looks smaller and better.
# Unicode no-break space U+00A0 is encoded as \xC2 \xA0 in UTF-8.
print "\xC2\xA0"
print "![Fatdog64 logo](img/fatdog64-header.png)"
print ""

}

# runs on ENDFILE before any other output, before END
function fd_footer (   ts) {
if (CURRENT_FILE ~ "faq_file_list")
	ts = ("This page was created on " strftime("%F") ".")
else
	ts = ("This page was automatically converted from " make_md_link(CURRENT_FILE) " on " strftime("%F") ".")
print ""
print "----"
print ""
print   "[Fatdog64](home.md)"
print "| [FAQ index](faq.md)"
print "| [FAQ files](faq_file_list.md)"
print "| [Fatdog64 online](https://distro.ibiblio.org/fatdog/web)"
print "| [FAQ online](https://distro.ibiblio.org/fatdog/web/faqs/faq.html)"
print ""
print "----"
print ""
print("_" ts "_")
}

function make_md_link(filename,   s) {
	sub(/.*\//, "", filename)
	sub(/\.[^.]*/, "", filename)
	s = ("[" filename ".html" "](" FATDOG_FAQ_DIR_URL "/" filename ".html)")
	gsub(/_/, "\\_", s)
	return s
}

