-- Shared functions for pandoc lua filters.

-- Read it again and again: https://pandoc.org/lua-filters.html#lua-filter-structure
-- Of course this one too: https://pandoc.org/lua-filters.html#lua-type-reference
-- Traversal order: https://pandoc.org/lua-filters.html#traversal-order
-- Simpler, about traversal: https://stackoverflow.com/questions/63024967

local shared = {}

function shared.contains (list, x)
	for _, v in pairs(list) do
		if v == x then return true end
	end
	return false
end

function shared.remove_all (list, x)
	local count = 0
	for i, v in ipairs(list) do
		if v == x then
			table.remove(list, i)
			count = count + 1
		end
	end
	return count
end

function shared.get_mdview_markdown ()
	mdview_markdown = os.getenv 'mdview_markdown'
	if not mdview_markdown or mdview_markdown == '' then
		mdview_markdown = 'markdown_strict'
	end
	return mdview_markdown
end

if PANDOC_STATE then

	function shared.get_input_filename ()
		if PANDOC_STATE.input_files then
			return PANDOC_STATE.input_files[1]
		end
		return "/dev/stdin"
	end

	-- return the text of an element
	function shared.get_item_text (iln)
		if iln.t == 'Str' then
			return iln.text
		elseif iln.t == 'Space' then
			return ' '
		end
		return ''
	end

	-- return List of texts of lo's Inlines list
	function shared.get_texts (lo)
		local acc = pandoc.List{}
		for _, li in pairs(lo) do
			acc:insert(shared.get_item_text(li))
		end
		return acc
	end

	-- --- convert a list of Inline elements to a string
	-- USE pandoc.utils.stringify instead of this function
	-- function shared.inlines_tostring (inlines)
	--   local strs = {}
	--   for i = 1, #inlines do
	--     strs[i] = tostring(inlines[i])
	--   end
	--   return table.concat(strs)
	-- end
end

return shared
